/*
 * $Id: Kreis.java $
 * 2006-05-23
 * by Arne Johannessen
 * based on BlueJ example project "shapes"
 * based on class Circle by Michael Kolling, David J. Barnes
 */


import java.awt.*;
import java.awt.geom.*;

/**
 * A circle that can be manipulated and that draws itself on a canvas.
 * 
 * @author	Michael Kolling and David J. Barnes
 * @version 1.0  (15 July 2000)
 */

public class Kreis
{
    private int diameter;
	private int xPosition;
	private int yPosition;
	private String color;
	private boolean isVisible;
	
    /**
     * Erstellt einen neuen Kreis in der Standardposition mit der Standardfarbe.
     */
    public Kreis()
    {
		diameter = 30;
		xPosition = 20;
		yPosition = 60;
		color = "blau";
		machSichtbar();
    }

	/**
	 * Make this circle visible. If it was already visible, do nothing.
	 */
	public void machSichtbar()
	{
		isVisible = true;
		draw();
	}
	
	/**
	 * Make this circle invisible. If it was already invisible, do nothing.
	 */
	public void machUnsichtbar()
	{
		erase();
		isVisible = false;
	}
	
    /**
     * Move the circle a few pixels to the right.
     */
    public void verschiebeNachRechts()
    {
		verschiebeHorizontal(20);
    }

    /**
     * Move the circle a few pixels to the left.
     */
    public void verschiebeNachLinks()
    {
		verschiebeHorizontal(-20);
    }

    /**
     * Move the circle a few pixels up.
     */
    public void verschiebeNachOben()
    {
		verschiebeVertikal(-20);
    }

    /**
     * Move the circle a few pixels down.
     */
    public void verschiebeNachUnten()
    {
		verschiebeVertikal(20);
    }

    /**
     * Bewegt den Kreis horizontal um "entfernung" Pixel.
     */
    public void verschiebeHorizontal(int entfernung)
    {
		erase();
		xPosition += entfernung;
		draw();
    }

    /**
     * Bewegt den Kreis vertikal um "entfernung" Pixel.
     */
    public void verschiebeVertikal(int entfernung)
    {
		erase();
		yPosition += entfernung;
		draw();
    }

    /**
     * Bewegt den Kreis langsam horizontal um "entfernung" Pixel.
     */
    public void verschiebeLangsamHorizontal(int entfernung)
    {
		int delta;

		if(entfernung < 0) 
		{
			delta = -1;
			entfernung = -entfernung;
		}
		else 
		{
			delta = 1;
		}

		for(int i = 0; i < entfernung; i++)
		{
			xPosition += delta;
			draw();
		}
    }

    /**
     * Bewegt den Kreis langsam vertikal um "entfernung" Pixel.
     */
    public void verschiebeLangsamVertikal(int entfernung)
    {
		int delta;

		if(entfernung < 0) 
		{
			delta = -1;
			entfernung = -entfernung;
		}
		else 
		{
			delta = 1;
		}

		for(int i = 0; i < entfernung; i++)
		{
			yPosition += delta;
			draw();
		}
    }

    /**
     * Setzt den Durchmesser des Kreises auf die angegebene Groesse
     * in Pixel. Der Durchmesser muss >= 0 sein.
     */
    public void aendereGroesse(int neuerDurchmesser)
    {
		erase();
		diameter = neuerDurchmesser;
		draw();
    }

    /**
     * Aendert die Farbe. Erlaubt sind "rot", "gelb", "blau", "gruen",
	 * "magenta" und "schwarz".
     */
    public void aendereFarbe(String neueFarbe)
    {
		color = neueFarbe;
		draw();
    }

	/*
	 * Draw the circle with current specifications on screen.
	 */
	private void draw()
	{
		if(isVisible) {
			Leinwand canvas = Leinwand.holeLeinwand();
			canvas.draw(this, color, new Ellipse2D.Double(xPosition, yPosition, 
														  diameter, diameter));
			canvas.wait(10);
		}
	}

	/*
	 * Erase the circle on screen.
	 */
	private void erase()
	{
		if(isVisible) {
			Leinwand canvas = Leinwand.holeLeinwand();
			canvas.erase(this);
		}
	}
}
